@@ -12,6 +12,11 @@ from .models import Text
 from .utils import plugin_tags_to_user_html
 from .forms import TextForm
 
+try:
+    from urlparse import urljoin
+except ImportError:
+    from urllib.parse import urljoin
+
 
 class TextPlugin(CMSPluginBase):
     model = Text
@@ -61,7 +66,7 @@ class TextPlugin(CMSPluginBase):
         We override the change form template path
         to provide backwards compatibility with CMS 2.x
         """
-        ckeditor_basepath = '{0}/ckeditor/'.format(settings.STATIC_URL)
+        ckeditor_basepath = urljoin(settings.STATIC_URL, 'djangocms_text_ckeditor/ckeditor/')
         if ckeditor_basepath.startswith('//'):
             protocol = 'https' if request.is_secure else 'http'
             ckeditor_basepath = '{0}:{1}'.format(protocol, ckeditor_basepath)
