@@ -1,12 +1,20 @@
 import re
+import sys
+
+try:
+    from django.utils.encoding import force_text as force_unicode_or_text
+except ImportError:
+    from django.utils.encoding import force_unicode as force_unicode_or_text
+
 from django.db import models
-from cms.models import CMSPlugin
 from django.utils.html import strip_tags
 from django.utils.text import Truncator
 from django.utils.translation import ugettext_lazy as _
-import sys
-from djangocms_text_ckeditor.utils import plugin_tags_to_id_list, replace_plugin_tags, plugin_to_tag
-from djangocms_text_ckeditor.html import clean_html, extract_images
+
+from cms.models import CMSPlugin
+
+from .utils import plugin_tags_to_id_list, replace_plugin_tags, plugin_to_tag
+from .html import clean_html, extract_images
 
 
 class AbstractText(CMSPlugin):
@@ -22,6 +30,10 @@ class AbstractText(CMSPlugin):
     def __unicode__(self):
         return Truncator(strip_tags(self.body)).words(3, truncate="...")
 
+    def __init__(self, *args, **kwargs):
+        super(AbstractText, self).__init__(*args, **kwargs)
+        self.body = force_unicode_or_text(self.body)
+
     def save(self, *args, **kwargs):
         body = self.body
         body = extract_images(body, self)
@@ -34,7 +46,8 @@ class AbstractText(CMSPlugin):
         plugins = CMSPlugin.objects.filter(parent=self)
         for plugin in plugins:
             if not plugin.pk in ids:
-                plugin.delete() #delete plugins that are not referenced in the text anymore
+                #delete plugins that are not referenced in the text anymore
+                plugin.delete()
 
     def post_copy(self, old_instance, ziplist):
         """
@@ -110,7 +123,7 @@ class AbstractText(CMSPlugin):
         order = 1
         for child in children:
             replacements['_tag_child_'+str(order)] = plugin_to_tag(child)
-            order+=1
+            order += 1
         self.body = self.body % replacements
         self.save()
 
